@@ -2,7 +2,8 @@ use core::future::Future;
 use core::pin::Pin;
 use core::task::{Context, Poll};
 
-use crate::set::Set;
+use crate::bias::Bias;
+use crate::set::{Number, Set};
 
 /// Index which indicates that all branches have been disabled.
 pub const DISABLED: u32 = u32::MAX;
@@ -22,7 +23,7 @@ pub const DISABLED: u32 = u32::MAX;
 /// ```
 /// use std::time::Duration;
 ///
-/// use selectme::Select;
+/// use selectme::{Random, Select};
 /// use tokio::time;
 ///
 /// # #[tokio::main] pub async fn main() {
@@ -31,7 +32,7 @@ pub const DISABLED: u32 = u32::MAX;
 ///
 /// let mut inlined_var = false;
 ///
-/// let output: Select<_, _> = selectme::inline! {
+/// let output: Select<u8, _, Random, _> = selectme::inline! {
 ///     () = s1 => {
 ///         inlined_var = true;
 ///         Some(1)
@@ -50,25 +51,29 @@ pub const DISABLED: u32 = u32::MAX;
 /// # }
 /// ```
 
-pub struct Select<S, T> {
-    snapshot: Set,
+pub struct Select<Bits, S, B, T> {
+    snapshot: Set<Bits>,
     state: S,
+    bias: B,
     poll: T,
 }
 
-impl<S, T> Select<S, T> {
-    pub(crate) fn new(snapshot: Set, state: S, poll: T) -> Self {
+impl<Bits, S, B, T> Select<Bits, S, B, T> {
+    pub(crate) fn new(snapshot: Set<Bits>, bias: B, state: S, poll: T) -> Self {
         Self {
             snapshot,
             state,
+            bias,
             poll,
         }
     }
 }
 
-impl<S, T, O> Select<S, T>
+impl<Bits, S, B, T, O> Select<Bits, S, B, T>
 where
-    T: FnMut(&mut Context<'_>, Pin<&mut S>, &mut Set, u32) -> Poll<O>,
+    Bits: Number,
+    B: Bias<Bits>,
+    T: FnMut(&mut Context<'_>, Pin<&mut S>, &mut Set<Bits>, u32) -> Poll<O>,
 {
     /// Get the next element from this select when pinned.
     ///
@@ -113,7 +118,7 @@ where
             let mut state = Pin::new_unchecked(&mut this.state);
 
             // All branches are disabled.
-            for index in this.snapshot.iter() {
+            for index in this.bias.apply(this.snapshot) {
                 if let Poll::Ready(output) =
                     (this.poll)(cx, state.as_mut(), &mut this.snapshot, index)
                 {
@@ -132,9 +137,11 @@ where
     }
 }
 
-impl<S, T, O> Future for Select<S, T>
+impl<Bits, S, B, T, O> Future for Select<Bits, S, B, T>
 where
-    T: FnMut(&mut Context<'_>, Pin<&mut S>, &mut Set, u32) -> Poll<O>,
+    Bits: Number,
+    B: Bias<Bits>,
+    T: FnMut(&mut Context<'_>, Pin<&mut S>, &mut Set<Bits>, u32) -> Poll<O>,
 {
     type Output = O;
 
@@ -143,13 +150,15 @@ where
     }
 }
 
-struct Next<'a, S, T> {
-    this: Pin<&'a mut Select<S, T>>,
+struct Next<'a, Bits, S, B, T> {
+    this: Pin<&'a mut Select<Bits, S, B, T>>,
 }
 
-impl<S, T, O> Future for Next<'_, S, T>
+impl<Bits, S, B, T, O> Future for Next<'_, Bits, S, B, T>
 where
-    T: FnMut(&mut Context<'_>, Pin<&mut S>, &mut Set, u32) -> Poll<O>,
+    Bits: Number,
+    B: Bias<Bits>,
+    T: FnMut(&mut Context<'_>, Pin<&mut S>, &mut Set<Bits>, u32) -> Poll<O>,
 {
     type Output = O;
 
