@@ -2,12 +2,13 @@ use core::future::Future;
 use core::pin::Pin;
 use core::task::{Context, Poll};
 
+use crate::bias::Bias;
 use crate::select::DISABLED;
-use crate::set::Set;
+use crate::set::{Number, Set};
 
 /// The type of a static poller function. This is produced when
 /// [inline!][crate::inline!] is used with the `static` option.
-type StaticPoll<S, O> = fn(&mut Context<'_>, Pin<&mut S>, &mut Set, u32) -> Poll<O>;
+type StaticPoll<Bits, S, O> = fn(&mut Context<'_>, Pin<&mut S>, &mut Set<Bits>, u32) -> Poll<O>;
 
 /// The implementation used by the [select!][crate::select!] macro internally
 /// and returned by the [inline!][crate::inline!] macro when the `static;`
@@ -25,13 +26,13 @@ type StaticPoll<S, O> = fn(&mut Context<'_>, Pin<&mut S>, &mut Set, u32) -> Poll
 /// use std::time::Duration;
 ///
 /// use pin_project::pin_project;
-/// use selectme::StaticSelect;
+/// use selectme::{Random, StaticSelect};
 /// use tokio::time::{self, Sleep};
 ///
 /// #[pin_project]
 /// struct MyFuture {
 ///     #[pin]
-///     select: StaticSelect<(Sleep, Sleep), Option<u32>>,
+///     select: StaticSelect<u8, (Sleep, Sleep), Random, Option<u32>>,
 /// }
 ///
 /// impl Future for MyFuture {
@@ -60,23 +61,34 @@ type StaticPoll<S, O> = fn(&mut Context<'_>, Pin<&mut S>, &mut Set, u32) -> Poll
 /// assert_eq!(my_future.await, Some(1));
 /// # }
 /// ```
-pub struct StaticSelect<S, O> {
-    snapshot: Set,
+pub struct StaticSelect<Bits, S, B, O> {
+    snapshot: Set<Bits>,
     state: S,
-    poll: StaticPoll<S, O>,
+    bias: B,
+    poll: StaticPoll<Bits, S, O>,
 }
 
-impl<S, O> StaticSelect<S, O> {
-    pub(crate) fn new(snapshot: Set, state: S, poll: StaticPoll<S, O>) -> Self {
+impl<Bits, S, B, O> StaticSelect<Bits, S, B, O> {
+    pub(crate) fn new(
+        snapshot: Set<Bits>,
+        bias: B,
+        state: S,
+        poll: StaticPoll<Bits, S, O>,
+    ) -> Self {
         Self {
             snapshot,
             state,
+            bias,
             poll,
         }
     }
 }
 
-impl<S, O> StaticSelect<S, O> {
+impl<Bits, S, B, O> StaticSelect<Bits, S, B, O>
+where
+    Bits: Number,
+    B: Bias<Bits>,
+{
     /// Get the next element from this select when pinned.
     ///
     /// # Examples
@@ -122,7 +134,7 @@ impl<S, O> StaticSelect<S, O> {
             let mut state = Pin::new_unchecked(&mut this.state);
 
             // All branches are disabled.
-            for index in this.snapshot.iter() {
+            for index in this.bias.apply(this.snapshot) {
                 if let Poll::Ready(output) =
                     (this.poll)(cx, state.as_mut(), &mut this.snapshot, index)
                 {
@@ -141,7 +153,11 @@ impl<S, O> StaticSelect<S, O> {
     }
 }
 
-impl<S, O> Future for StaticSelect<S, O> {
+impl<Bits, S, B, O> Future for StaticSelect<Bits, S, B, O>
+where
+    Bits: Number,
+    B: Bias<Bits>,
+{
     type Output = O;
 
     fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
@@ -149,11 +165,15 @@ impl<S, O> Future for StaticSelect<S, O> {
     }
 }
 
-struct Next<'a, S, O> {
-    this: Pin<&'a mut StaticSelect<S, O>>,
+struct Next<'a, Bits, S, B, O> {
+    this: Pin<&'a mut StaticSelect<Bits, S, B, O>>,
 }
 
-impl<S, O> Future for Next<'_, S, O> {
+impl<Bits, S, B, O> Future for Next<'_, Bits, S, B, O>
+where
+    Bits: Number,
+    B: Bias<Bits>,
+{
     type Output = O;
 
     fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
